"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useGlobalState = void 0;
const react_1 = require("react");
const globalState = {};
const funcToggleValue = (v) => !v;
const useGlobalState = (stateName, initValue, listening = true) => {
    const [, setToggleState] = (0, react_1.useState)(false);
    let state = globalState[stateName];
    if (!state) {
        state = {
            value: initValue,
            statesListening: new Set(),
            set(newValue) {
                const oldValue = state.value;
                state.value = newValue instanceof Function ? newValue(oldValue) : newValue;
                if (state.value !== oldValue) {
                    state.statesListening.forEach((setState) => setState(funcToggleValue));
                }
            },
        };
        globalState[stateName] = state;
    }
    if (listening) {
        state.statesListening.add(setToggleState);
    }
    (0, react_1.useEffect)(() => () => {
        state.statesListening.delete(setToggleState);
    }, [state.statesListening]);
    return [state.value, state.set];
};
exports.useGlobalState = useGlobalState;
exports.default = exports.useGlobalState;
